__author__ = "Prahlad Yeri"
__email__ = "prahladyeri@yahoo.com"
__copyright__ = "(c) 2019 Prahlad Yeri"

__license__ = "MIT"
__version__ = "1.0.1"
__title__ = 'cfgsaver'
__description__ = 'Module to save and fetch configuration data in a standard path and format.'